@@ -19,6 +19,7 @@
 #include <libecal/e-cal.h>
 #include <libedataserver/e-time-utils.h>
 #include "lib/sunone-util.h"
+#include "calendar/cal-backend-wcap-events.h"
 #include "sunone-invitation-list-model.h"
 #include "sunone-component.h"
 #include "sunone-offline-listener.h"
@@ -340,9 +341,13 @@ get_value (GtkTreeModel *model, GtkTreeIter *iter, int col, GValue *value)
 		e_cal_component_get_attendee_list (id->comp, &attendees);
 		for (l = attendees; l != NULL; l = l->next) {
 			ECalComponentAttendee *a = l->data;
+			const char *attendee = a->value;
 			
-			/* FIXME: Look for email addresses as well */
-			if (!strcasecmp (list_model->priv->calid, a->value))
+			if (!strncasecmp ("mailto:", attendee, 7)) {
+				attendee = attendee + 7;
+			}
+			if (!strcasecmp (list_model->priv->calid, attendee) ||
+				!strcasecmp (sunone_account_get_email (list_model->account), attendee))
 				status = a->status;
 		}
 		e_cal_component_free_attendee_list (attendees);
@@ -657,9 +662,11 @@ sunone_invitation_list_model_set_value (SunOneInvitationListModel *model, int co
 {
 	SunOneInvitationListModelPrivate *priv = model->priv;
 	SunOneInvitationData *id;
-	icalcomponent *icalcomp, *newcomp;
+	icalcomponent *icalcomp, *clonecomp;
 	icalproperty *prop;
 	SunOneConnection *cnc;
+	CalBackendWCAP *wcap;
+	char *key;
 
 	cnc = sunone_account_get_connection (model->account);
 	
@@ -668,16 +675,10 @@ sunone_invitation_list_model_set_value (SunOneInvitationListModel *model, int co
  	case STATUS_COL:
 		icalcomp = e_cal_component_get_icalcomponent (id->comp);
 
-		newcomp = icalcomponent_new (icalcomponent_isa (icalcomp));
-		prop = icalcomponent_get_first_property (icalcomp, ICAL_UID_PROPERTY);
-		icalcomponent_add_property (newcomp, icalproperty_new_clone (prop));
-					 
 		for (prop = icalcomponent_get_first_property (icalcomp, ICAL_ATTENDEE_PROPERTY);
-		     prop != NULL;
-		     prop = icalcomponent_get_next_property (icalcomp, ICAL_ATTENDEE_PROPERTY))
-		{
+			 prop != NULL;
+			 prop = icalcomponent_get_next_property (icalcomp, ICAL_ATTENDEE_PROPERTY)) {
 			icalvalue *value;
-			icalproperty *newprop;
 			icalparameter *param;
 			const char *attendee;
 			icalparameter_partstat status = ICAL_PARTSTAT_NEEDSACTION;
@@ -687,8 +688,10 @@ sunone_invitation_list_model_set_value (SunOneInvitationListModel *model, int co
 				continue;
 
 			attendee = icalvalue_get_string (value);
-			/* FIXME: Look for email addresses as well */
-			if (!strcasecmp (priv->calid, attendee)) {
+			if (!strncasecmp ("mailto:", attendee, 7)) {
+				attendee = attendee + 7;
+			} if (!strcasecmp (priv->calid, attendee) ||
+				!strcasecmp (sunone_account_get_email (model->account), attendee)) {
 				if (!strcmp (val, _("Needs Action")))
 					status = ICAL_PARTSTAT_NEEDSACTION;
 				else if (!strcmp (val, _("Accepted")))
@@ -698,25 +701,22 @@ sunone_invitation_list_model_set_value (SunOneInvitationListModel *model, int co
 				else if (!strcmp (val, _("Tentative")))
 					status = ICAL_PARTSTAT_TENTATIVE;
 
-				newprop = icalproperty_new_clone (prop);
-				icalcomponent_add_property (newcomp, newprop);
-
 				icalproperty_remove_parameter (prop, ICAL_PARTSTAT_PARAMETER);
 				param = icalparameter_new_partstat (status);
 				icalproperty_add_parameter (prop, param);
 
-				icalproperty_remove_parameter (newprop, ICAL_PARTSTAT_PARAMETER);
-				param = icalparameter_new_partstat (status);
-				icalproperty_add_parameter (newprop, param);
-
 				e_cal_component_rescan (id->comp);
 			}
 		}
 
-		sunone_connection_storeevents (cnc, priv->calid,
-					       newcomp, REPLY, THISANDALL, TRUE, FALSE, NULL,
-							sunone_account_get_email (model->account));
-		icalcomponent_free (newcomp);
+		clonecomp = icalcomponent_new_clone(icalcomp);
+		key = g_strconcat (priv->calid, ":calendar", NULL);
+		wcap = sunone_connection_get_wcap (cnc, key);
+		g_free (key);
+		if (wcap)
+			cal_backend_wcap_events_update_objects (E_CAL_BACKEND_SYNC (wcap), NULL,
+					icalcomponent_as_ical_string (clonecomp), CALOBJ_MOD_ALL, NULL, NULL);
+		icalcomponent_free (clonecomp);
 	}
 }
 
